# iRe.py
Export tables and plots from Jupyter notebooks, along with metadata for embedding interactive tables in downstream apps.

See [iRe/www], which renders notebooks annotated by iRe.py as interactive reports.

## Installation
```bash
pip install ire.py
```

## Usage
See [examples/](examples):
- [export-test.ipynb](examples/export-test.ipynb)
- [export-test-no-dvc.ipynb](examples/export-test-no-dvc.ipynb)

## Testing
See [.gitlab-ci.yml](.gitlab-ci.yml).

[iRe/www]: https://gitlab.com/runsascoded/ire/www
